==> lxqt-powermanagement-1.1.0.tar.xz: lxqt-powermanagement-1.1.0/src/translations/lxqt-powermanagement_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Empty</source>
        <translation>Leer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>Vollständig aufgeladen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>Aufladen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>Lithium-Ionen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>Lithium-Polymer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium-Eisenphosphat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>Blei</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>Nickel-Cadmium</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>Nickel-Metallhydrid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Personal-Digital-Assistant-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Unterbrechungsfreie-Stromversorgung-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>Primäre Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>Maus-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>Tastatur-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Tastatur-und-Maus-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>Kamera-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>Telefon-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>Bildschirm-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>Unbekannte Batterie</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Batterie-Info</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatur:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Vorgabe-Ladung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Maximale Ladung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Aktuelle Ladung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Ladungsrate:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technologie:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Spannung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Hersteller:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Keine Batterie!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt konnte keine Daten über eine Batterie finden - Überwachung deaktiviert</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>Niedrige Ladung!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Bereitschaftsmodus in %n Sekunde(n)</numerusform>
            <numerusform>Bereitschaftsmodus in %n Sekunden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Ruhezustand in %n Sekunde(n)</numerusform>
            <numerusform>Ruhezustand in %n Sekunden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Herunterfahren in %n Sekunde(n)</numerusform>
            <numerusform>Herunterfahren in %n Sekunden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Ausschalt-Tastenaktion</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Bereitschaftszustand-Tastenaktion</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Ruhezustand-Tastenaktion</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Sie führen die LXQt-Energieverwaltung erstmals aus.
Sie können sie in den Einstellungen konfigurieren... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Konfigurieren...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="67"/>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="75"/>
        <source>30 minutes</source>
        <translation>30 Minuten</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="79"/>
        <source>1 hour</source>
        <translation>1 Stunde</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="83"/>
        <source>2 hours</source>
        <translation>2 Stunden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="87"/>
        <source>3 hours</source>
        <translation>3 Stunden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="91"/>
        <source>4 hours</source>
        <translation>4 Stunden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="96"/>
        <source>Pause idleness checks</source>
        <translation>Leerlaufprüfungen pausieren</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="101"/>
        <location filename="../trayicon.cpp" line="191"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="103"/>
        <source>Disable icon</source>
        <translation>Symbol deaktivieren</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="192"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;LXQt-Energieverwaltung&lt;/b&gt;&lt;br/&gt;  - Energieverwaltung für die LXQt-Desktop-Umgebung&lt;/p&gt;&lt;p&gt;  Autoren:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - und Andere aus den Razor- und LXQt-Projekten&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="210"/>
        <source>LXQt Power Management info</source>
        <translation>LXQt-Energieverwaltung-Info</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="211"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Das LXQt-Energieverwaltung-Systemleistensymbol kann in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt; (wieder) aktiviert werden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="213"/>
        <source>Configure now</source>
        <translation>Jetzt konfigurieren</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_1.2.0.orig.tar.xz: lxqt-powermanagement-1.2.0/src/translations/lxqt-powermanagement_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Stable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Discharging</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="48"/>
        <source>Fully charged</source>
        <translation>Vollständig aufgeladen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="51"/>
        <source>Charging</source>
        <translation>Aufladen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium ion</source>
        <translation>Lithium-Ionen</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium polymer</source>
        <translation>Lithium-Polymer</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium-Eisenphosphat</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Lead acid</source>
        <translation>Blei</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel cadmium</source>
        <translation>Nickel-Cadmium</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="70"/>
        <source>Nickel metal hydride</source>
        <translation>Nickel-Metallhydrid</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Personal-Digital-Assistant-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Unterbrechungsfreie-Stromversorgung-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Primary battery</source>
        <translation>Primäre Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Mouse battery</source>
        <translation>Maus-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard battery</source>
        <translation>Tastatur-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Tastatur-und-Maus-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Camera battery</source>
        <translation>Kamera-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Phone battery</source>
        <translation>Telefon-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="98"/>
        <source>Monitor battery</source>
        <translation>Bildschirm-Batterie</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="101"/>
        <source>Unknown battery</source>
        <translation>Unbekannte Batterie</translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="111"/>
        <source>%Ln hour(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batteryhelper.cpp" line="112"/>
        <source>%Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="117"/>
        <source>remaining %1</source>
        <translation>%1 verbleiben</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="122"/>
        <source>to full %1</source>
        <translation>%1 bis voll</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Batterie-Info</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatur:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Vorgabe-Ladung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Maximale Ladung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Aktuelle Ladung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Ladungsrate:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technologie:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Spannung:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Hersteller:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.cpp" line="65"/>
        <source>Empty</source>
        <translation type="unfinished">Leer</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Keine Batterie!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt konnte keine Daten über eine Batterie finden - Überwachung deaktiviert</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="119"/>
        <source>Power low!</source>
        <translation>Niedrige Ladung!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Suspending in %Ln second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="134"/>
        <source>Hibernating in %Ln second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="137"/>
        <source>Shutting down in %Ln second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation>Ausschalt-Tastenaktion</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation>Bereitschaftszustand-Tastenaktion</translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation>Ruhezustand-Tastenaktion</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Sie führen die LXQt-Energieverwaltung erstmals aus.
Sie können sie in den Einstellungen konfigurieren... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Konfigurieren...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="67"/>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="75"/>
        <source>30 minutes</source>
        <translation>30 Minuten</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="79"/>
        <source>1 hour</source>
        <translation>1 Stunde</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="83"/>
        <source>2 hours</source>
        <translation>2 Stunden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="87"/>
        <source>3 hours</source>
        <translation>3 Stunden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="91"/>
        <source>4 hours</source>
        <translation>4 Stunden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="96"/>
        <source>Pause idleness checks</source>
        <translation>Leerlaufprüfungen pausieren</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="101"/>
        <location filename="../trayicon.cpp" line="193"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="103"/>
        <source>Disable icon</source>
        <translation>Symbol deaktivieren</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="162"/>
        <source>Empty</source>
        <translation type="unfinished">Leer</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="194"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;LXQt-Energieverwaltung&lt;/b&gt;&lt;br/&gt;  - Energieverwaltung für die LXQt-Desktop-Umgebung&lt;/p&gt;&lt;p&gt;  Autoren:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - und Andere aus den Razor- und LXQt-Projekten&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="212"/>
        <source>LXQt Power Management info</source>
        <translation>LXQt-Energieverwaltung-Info</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="213"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Das LXQt-Energieverwaltung-Systemleistensymbol kann in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt; (wieder) aktiviert werden</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="215"/>
        <source>Configure now</source>
        <translation>Jetzt konfigurieren</translation>
    </message>
</context>
</TS>
